==> huaweicloudsdkmeeting-3.0.49-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/qos_data_no_thr_element.py <==
# coding: utf-8

import pprint
import re

import six





class QosDataNoThrElement:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'time': 'str',
        'value': 'str'
    }

    attribute_map = {
        'time': 'time',
        'value': 'value'
    }

    def __init__(self, time=None, value=None):
        """QosDataNoThrElement - a model defined in huaweicloud sdk"""
        
        

        self._time = None
        self._value = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if value is not None:
            self.value = value

    @property
    def time(self):
        """Gets the time of this QosDataNoThrElement.

        Qos时间点, UTC时间，格式：yyyy-MM-ddTHH:mm:ss.SSSZ。

        :return: The time of this QosDataNoThrElement.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this QosDataNoThrElement.

        Qos时间点, UTC时间，格式：yyyy-MM-ddTHH:mm:ss.SSSZ。

        :param time: The time of this QosDataNoThrElement.
        :type: str
        """
        self._time = time

    @property
    def value(self):
        """Gets the value of this QosDataNoThrElement.

        QoS值。

        :return: The value of this QosDataNoThrElement.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this QosDataNoThrElement.

        QoS值。

        :param value: The value of this QosDataNoThrElement.
        :type: str
        """
        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QosDataNoThrElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmeeting-3.0.51-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/qos_data_no_thr_element.py <==
# coding: utf-8

import re
import six





class QosDataNoThrElement:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'time': 'str',
        'value': 'str'
    }

    attribute_map = {
        'time': 'time',
        'value': 'value'
    }

    def __init__(self, time=None, value=None):
        """QosDataNoThrElement - a model defined in huaweicloud sdk"""
        
        

        self._time = None
        self._value = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if value is not None:
            self.value = value

    @property
    def time(self):
        """Gets the time of this QosDataNoThrElement.

        Qos时间点, UTC时间，格式：yyyy-MM-ddTHH:mm:ss.SSSZ。

        :return: The time of this QosDataNoThrElement.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this QosDataNoThrElement.

        Qos时间点, UTC时间，格式：yyyy-MM-ddTHH:mm:ss.SSSZ。

        :param time: The time of this QosDataNoThrElement.
        :type: str
        """
        self._time = time

    @property
    def value(self):
        """Gets the value of this QosDataNoThrElement.

        QoS值。

        :return: The value of this QosDataNoThrElement.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this QosDataNoThrElement.

        QoS值。

        :param value: The value of this QosDataNoThrElement.
        :type: str
        """
        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QosDataNoThrElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
